Crate rmf_site_editor

Crate rmf_site_editor 

Re-exports

pub use bevy;
pub use bevy_egui;
pub use crossflow;
pub use autoload::*;
pub use osm_slippy_map::*;

Modules

aabb
asset_loaders
autoload
color_picker
demo_world
exit_confirmation
interaction
issue
keyboard
layers
log
main_menu
mapf_rse
occupancy
osm_slippy_map
sdf_loader
site
site_asset_io
widgets
The site editor allows you to insert your own egui widgets into the UI. Simple examples of custom widgets can be found in the docs for PropertiesTilePlugin and InspectionPlugin.
wireframe
workspace

Structs

CommandLineArgs
DebugMode
SiteEditor
Text3dPlugin
Text3d Plugin, add [Text3dPluginSettings] before this to modify its behavior.

Enums

AppState

Functions

run