Re-exports
pub use bevy;pub use bevy_egui;pub use crossflow;pub use autoload::*;pub use osm_slippy_map::*;
Modules
- aabb
- asset_
loaders - autoload
- color_
picker - demo_
world - exit_
confirmation - interaction
- issue
- keyboard
- layers
- log
- main_
menu - mapf_
rse - occupancy
- osm_
slippy_ map - sdf_
loader - site
- site_
asset_ io - widgets
- The site editor allows you to insert your own egui widgets into the UI.
Simple examples of custom widgets can be found in the docs for
PropertiesTilePluginandInspectionPlugin. - wireframe
- workspace
Structs
- Command
Line Args - Debug
Mode - Site
Editor - Text3d
Plugin - Text3d Plugin, add [
Text3dPluginSettings] before this to modify its behavior.